==> ejc-jlprogress-impl-3.0.0-20241111.102036-407-sources.jar: com/ejianc/business/jlprogress/factory/bean/FactJigaiDetailEntity.java <==
package com.ejianc.business.jlprogress.factory.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 制造厂-技改项目进度明细表
 *
 * @author generator
 *
 */
 @TableName("ejc_factory_jigai_detail")
public class FactJigaiDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="jigai_id")
    private Long jigaiId; // 主表ID
    @TableField(value="project_memo")
    private String projectMemo; // 项目简介
    @TableField(value="self_mny")
    private BigDecimal selfMny; // 自产金额
    @TableField(value="out_mny")
    private BigDecimal outMny; // 外购金额
    @TableField(value="pre_num")
    private BigDecimal preNum; // 预计投产数量
    @TableField(value="manager")
    private String manager; // 项目负责人
    @TableField(value="progress_desc")
    private String progressDesc; // 进度说明
    @TableField(value="pre_finish_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date preFinishDate; // 预计完工时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="begin_end_date")
    private String beginEndDate; // 项目名称




    public Long getJigaiId() {
        return jigaiId;
    }

    public void setJigaiId(Long jigaiId) {
        this.jigaiId = jigaiId;
    }
    public String getProjectMemo() {
        return projectMemo;
    }

    public void setProjectMemo(String projectMemo) {
        this.projectMemo = projectMemo;
    }
    public BigDecimal getSelfMny() {
        return selfMny;
    }

    public void setSelfMny(BigDecimal selfMny) {
        this.selfMny = selfMny;
    }
    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    public BigDecimal getPreNum() {
        return preNum;
    }

    public void setPreNum(BigDecimal preNum) {
        this.preNum = preNum;
    }
    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }
    public String getProgressDesc() {
        return progressDesc;
    }

    public void setProgressDesc(String progressDesc) {
        this.progressDesc = progressDesc;
    }
    public Date getPreFinishDate() {
        return preFinishDate;
    }

    public void setPreFinishDate(Date preFinishDate) {
        this.preFinishDate = preFinishDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBeginEndDate() {
        return beginEndDate;
    }

    public void setBeginEndDate(String beginEndDate) {
        this.beginEndDate = beginEndDate;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241127.013018-459-sources.jar: com/ejianc/business/jlprogress/factory/bean/FactJigaiDetailEntity.java <==
package com.ejianc.business.jlprogress.factory.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 制造厂-技改项目进度明细表
 *
 * @author generator
 *
 */
 @TableName("ejc_factory_jigai_detail")
public class FactJigaiDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="jigai_id")
    private Long jigaiId; // 主表ID
    @TableField(value="project_memo")
    private String projectMemo; // 项目简介
    @TableField(value="self_mny")
    private BigDecimal selfMny; // 自产金额
    @TableField(value="out_mny")
    private BigDecimal outMny; // 外购金额
    @TableField(value="pre_num")
    private String preNum; // 预计投产数量
    @TableField(value="manager")
    private String manager; // 项目负责人
    @TableField(value="progress_desc")
    private String progressDesc; // 进度说明
    @TableField(value="pre_finish_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date preFinishDate; // 预计完工时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="begin_end_date")
    private String beginEndDate; // 项目名称




    public Long getJigaiId() {
        return jigaiId;
    }

    public void setJigaiId(Long jigaiId) {
        this.jigaiId = jigaiId;
    }
    public String getProjectMemo() {
        return projectMemo;
    }

    public void setProjectMemo(String projectMemo) {
        this.projectMemo = projectMemo;
    }
    public BigDecimal getSelfMny() {
        return selfMny;
    }

    public void setSelfMny(BigDecimal selfMny) {
        this.selfMny = selfMny;
    }
    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    public String getPreNum() {
        return preNum;
    }

    public void setPreNum(String preNum) {
        this.preNum = preNum;
    }
    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }
    public String getProgressDesc() {
        return progressDesc;
    }

    public void setProgressDesc(String progressDesc) {
        this.progressDesc = progressDesc;
    }
    public Date getPreFinishDate() {
        return preFinishDate;
    }

    public void setPreFinishDate(Date preFinishDate) {
        this.preFinishDate = preFinishDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBeginEndDate() {
        return beginEndDate;
    }

    public void setBeginEndDate(String beginEndDate) {
        this.beginEndDate = beginEndDate;
    }
}
